@@ -1,5 +1,4 @@
 from ocp_resources.logger import get_logger
-from ocp_resources.resource import Resource
 
 
 LOGGER = get_logger(name=__name__)
@@ -10,7 +9,7 @@ class Event:
     Allow read and remove K8s events.
     """
 
-    api_version = Resource.ApiVersion.V1
+    api_version = "v1"
 
     @classmethod
     def get(
@@ -25,14 +24,19 @@ class Event:
     ):
         """
         get - retrieves K8s events.
-        :param dyn_client: K8s client; mandatory
-        :param namespace: event namespace; optional
-        :param name: event name; optional
-        :param label_selector: filter events by labels; comma separated string of key=value; optional
-        :param field_selector: filter events by event fields; comma separated string of key=value; optional
-        :param resource_version: filter events by their resource's version; optional
-        :param timeout: timeout; optional
-        :return: list of event objects
+
+        Args:
+            dyn_client (DynamicClient): K8s client
+            namespace (str): event namespace
+            name (str): event name
+            label_selector (str): filter events by labels; comma separated string of key=value
+            field_selector (str): filter events by fields; comma separated string of key=valueevent fields;
+                comma separated string of key=value
+            resource_version (str): filter events by their resource's version
+            timeout (int): timeout in seconds
+
+        Returns
+            list: event objects
 
         example: reading all CSV Warning events in namespace "my-namespace", with reason of "AnEventReason"
               for event in Event.get(
@@ -74,20 +78,24 @@ class Event:
         timeout=None,
     ):
         """
-        delete_events - delete K8s events. For example, to cleanup events before test, in order to not get old events in
-                        the test, in order to prevent false positive test.
-        :param dyn_client: K8s client; mandatory
-        :param namespace: event namespace; optional
-        :param name: event name; optional
-        :param label_selector: filter events by labels; comma separated string of key=value; optional
-        :param field_selector: filter events by event fields; comma separated string of key=value; optional
-        :param resource_version: filter events by their resource's version; optional
-        :param timeout: timeout; optional
-        :return: list of event objects
+        delete_events - delete K8s events. For example, to cleanup events before test, in order to not get old
+            events in the test, in order to prevent false positive test.
+
+        Args:
+            dyn_client (DynamicClient): K8s client
+            namespace (str): event namespace
+            name (str): event name
+            label_selector (str): filter events by labels; comma separated string of key=value
+            field_selector (str): filter events by fields; comma separated string of key=valueevent fields;
+                comma separated string of key=value
+            resource_version (str): filter events by their resource's version
+            timeout (int): timeout in seconds
+
+        Returns
+            list: event objects
 
         example: deleting all the event with a reason of "AnEventReason", from "my-namespace" namespace
 
-        @pytest.fixture()
         def delete_events_before_test(default_client):
           Event.delete_events(default_client, namespace=my-namespace, field_selector="reason=AnEventReason")
         """
